@@ -7,20 +7,22 @@ use strictures 2;
 use Carp;
 our @CARP_NOT = qw( Beam::Emitter );
 
-use List::Util qw[ first uniqstr ];
+use List::Util qw[ all first uniqstr ];
 use Scalar::Util qw[ refaddr weaken ];
 use Data::OptList qw[ mkopt ];
 use Safe::Isa;
 use Ref::Util qw[ is_arrayref ];
 use Types::Standard ':all';
+use Sub::Quote;
 
 use Moo::Role;
 
 use MooX::ProtectedAttributes;
 
-our $VERSION = '0.05'; # TRIAL
+our $VERSION = '0.06'; # TRIAL
 
 use Net::Object::Peer::Event;
+use Net::Object::Peer::Types qw[ -all ];
 use Net::Object::Peer::UnsubscribeEvent;
 use Net::Object::Peer::Listener;
 use Net::Object::Peer::Emitter;
@@ -43,6 +45,7 @@ use Sub::QuoteX::Utils qw[ quote_subs ];
 #pod
 #pod =cut
 
+use constant UNSUBSCRIBED     => 'unsubscribed';
 use constant UnsubscribeEvent => __PACKAGE__ . '::UnsubscribeEvent';
 use constant Emitter          => __PACKAGE__ . '::Emitter';
 
@@ -63,6 +66,98 @@ protected_has _emitter => (
     handles  => [qw< emit_args send_args >],
 );
 
+#pod =attr event_handler_prefix
+#pod
+#pod The string which prefixes default event handler method names. See
+#pod L</subscribe>.  It will by default be initialized to the return value
+#pod of the L</default_event_handler_prefix> method.  It may be specified
+#pod during object construction.
+#pod
+#pod For example, the default handler method name for an event named
+#pod C<changed> would be C<_cb_changed>.  The class must provide that
+#pod method. See L</subscribe> for more information.
+#pod
+#pod =cut
+
+has event_handler_prefix => (
+    is      => 'lazy',
+    isa     => Str,
+    builder => sub { $_[0]->default_event_handler_prefix },
+);
+
+
+
+has _events_arr => (
+    is      => 'rwp',
+    isa     => ArrayRef [Identifier],
+    coerce  => qsub q{ 'ARRAY' eq ref $_[0] ? [ @{$_[0]} ] : [ $_[0] ]; },
+    default => qsub q{ ['detach', 'unsubscribed', $_[0]->default_events ]; },
+    init_arg => 'events',
+    trigger => 1
+);
+
+has _events_hash => (
+    is        => 'lazy',
+    init_args => undef,
+    clearer   => 1,
+);
+
+sub _trigger__events_arr {
+
+    my $self = shift;
+
+    # force rebuild of _events attribute
+    $self->_clear_events_hash;
+
+    # _events gives us a unique list which includes the standard ones.
+    # we know that we own the arrayref in $self->events because of the
+    # its coercion.
+    @{ $self->_events_arr } = keys %{ $self->_events_hash };
+}
+
+sub _build__events_hash {
+
+    my %events = ( detach => 1, unsubscribed => 1 );
+
+    my $events_arr = $_[0]->_events_arr;
+
+    # just need to populate the keys
+    @events{ @{ $events_arr } } = undef
+      if $events_arr;
+
+    \%events;
+}
+
+#pod =method  emits_events
+#pod
+#pod    $bool = $obj->emits_events( @event_names );
+#pod
+#pod Returns true if the object emits I<all> of the named events
+#pod
+#pod =cut
+
+sub emits_events {
+
+    my $self = shift;
+    my $events = $self->_events_hash;
+
+    return all { exists $events->{$_} } @_;
+}
+
+#pod =method  default_events
+#pod
+#pod   @events = $class->default_events;
+#pod
+#pod Returns a list of events which this class will emit, excluding the C<detach> and C<unsubscribed> events.
+#pod The default implementation returns an empty list.  A per object event list may be specified via
+#pod the L</events> attribute or the C<events> option to the L<constructor|/new>.
+#pod
+#pod =cut
+
+sub default_events { }
+
+
+
 #pod =attr addr
 #pod
 #pod A L<Net::Object::Peer::RefAddr> object providing a unique identity for this emitter.
@@ -70,10 +165,10 @@ protected_has _emitter => (
 #pod =cut
 
 has addr => (
-	     is => 'rwp',
-	     isa => InstanceOf[ 'Net::Object::Peer::RefAddr' ],
-	     init_arg => undef,
-	     predicate => 1,
+    is        => 'rwp',
+    isa       => InstanceOf ['Net::Object::Peer::RefAddr'],
+    init_arg  => undef,
+    predicate => 1,
 );
 
 #pod =begin pod_coverage
@@ -86,7 +181,7 @@ has addr => (
 #pod
 #pod =cut
 
-sub BUILD {}
+sub BUILD { }
 
 before BUILD => sub {
 
@@ -96,6 +191,38 @@ before BUILD => sub {
 };
 
 
+#pod =method new
+#pod
+#pod   $obj = Net::Object::Peer->new( %args | \%args );
+#pod
+#pod Construct a new object.  The following arguments are available:
+#pod
+#pod =over
+#pod
+#pod =item event_handler_prefix => I<string>
+#pod
+#pod The string which prefixes default event handler method names. See L</event_handler_prefix>
+#pod
+#pod =item events => I<string> | I<arrayref>
+#pod
+#pod The name(s) of the event(s) this object will emit (don't include the
+#pod C<unsubscribed> and C<detach> events).  May be a single string or an
+#pod arrayref. If not specified, the list of events will be initialized via the
+#pod L</default_events> class method.
+#pod
+#pod =back
+#pod
+#pod =cut
+
+#pod =method default_event_handler_prefix
+#pod
+#pod This class method returns the prefix for the default event handler method names.
+#pod It defaults to returning C<_cb_>.
+#pod
+#pod =cut
+
+sub default_event_handler_prefix { '_cb_' }
+
 #pod =method build_sub
 #pod
 #pod   $coderef = $self->build_sub( $emitter, @tuple );
@@ -134,7 +261,7 @@ sub build_sub {
 
         if ( !defined $arg ) {
 
-            quote_subs( [ $self, "_cb_$name" ] );
+            quote_subs( [ $self, $self->event_handler_prefix . $name ] );
         }
 
         elsif ( 'HASH' eq ref $arg ) {
@@ -180,6 +307,8 @@ sub build_sub {
 #pod the L<Net::Object::Peer> role.  If C<$peer> additionally consumes the
 #pod L<Net::Object::Peer::Ephemeral> role, a strong reference to C<$peer>
 #pod is stored. (See  L<Net::Object::Peer::Cookbook/Translation/Proxy Nodes>.)
+#pod An attempt to subscribe to an event the peer does not produce will throw
+#pod an exception.
 #pod
 #pod The event name and the action to be performed when the event is
 #pod emitted are specified by a tuple with the following forms:
@@ -188,7 +317,8 @@ sub build_sub {
 #pod
 #pod =item C<< $event_name >>
 #pod
-#pod the event handler will invoke the C<_cb_${event_name}> method on C<$self>.
+#pod the event handler will invoke the C<${prefix}${event_name}> method on C<$self>,
+#pod where C<$prefix> is the L<event_handler_prefix attribute|/event_handler_prefix>.
 #pod
 #pod =item C<< $event_name => { method => $method_name } >>
 #pod
@@ -245,6 +375,10 @@ sub subscribe {
 
         croak( "\$name must be a string\n" )
           if ref $name;
+
+	croak( qq[\$peer does not emit event "$name" ] )
+	  unless $peer->emits_events( $name );
+
         push @register, [ $name, $self->build_sub( $peer, $name, $arg ) ];
     }
 
@@ -292,7 +426,7 @@ sub subscribe {
 #pod   # Unsubscribe from one or more events emitted by all peers
 #pod   $self->unsubscribe( $event_name [, $event_name [, ... ] ] )
 #pod
-#pod Unsubscribe from events/peers. After unsubscription, an I<unsubscribe>
+#pod Unsubscribe from events/peers. After unsubscription, an I<unsubscribed>
 #pod event with a L<Net::Object::Peer::UnsubscribeEvent> as a payload will
 #pod be sent to affected peers who have subscribed to the unsubscribed event(s).
 #pod
@@ -327,7 +461,7 @@ sub unsubscribe {
     }
     elsif ( $_[0]->$_isa( 'Net::Object::Peer::Event' ) ) {
 
-	$self->_unsubscribe_from_peer_events( $_[0]->addr, $_[0]->name );
+        $self->_unsubscribe_from_peer_events( $_[0]->addr, $_[0]->name );
 
     }
 
@@ -340,15 +474,11 @@ sub _unsubscribe_all {
 
     my $self = shift;
 
-    # say $self->name, ":\tunsubscribing from all peers";
-
-    $self->_subscriptions->remove;
+    $self->_subscriptions->remove
+      if defined $self->_subscriptions;
 
     # signal peers that unsubscribe has happened.
-
-    # say $self->name, ":\tnotifying all subscribed peers of unsubscription";
-
-    $self->emit( 'unsubscribe', class => UnsubscribeEvent );
+    $self->emit( UNSUBSCRIBED, class => UnsubscribeEvent );
 
     return;
 }
@@ -358,9 +488,9 @@ sub _find_peer_spec {
     my $peer = shift;
 
     return (
-          $peer->$_does( __PACKAGE__ )                  ? ( peer => $peer )
+          $peer->$_does( __PACKAGE__ )               ? ( peer => $peer )
         : $peer->isa( 'Net::Object::Peer::RefAddr' ) ? ( addr => $peer )
-        : croak( "can't grok \$peer: $peer\n" ),
+        :   croak( "can't grok \$peer: $peer\n" ),
     );
 
 }
@@ -391,7 +521,7 @@ sub _unsubscribe_from_peer_events {
     if ( @unsubs ) {
 
         $self->send(
-            $peer, 'unsubscribe',
+            $peer, UNSUBSCRIBED,
             class       => UnsubscribeEvent,
             event_names => [ uniqstr map { $_->{name} } @unsubs ] );
     }
@@ -421,7 +551,7 @@ sub _unsubscribe_from_peer {
         $peer = $sub->{peer};
     }
 
-    $self->send( $peer, 'unsubscribe', class => UnsubscribeEvent );
+    $self->send( $peer, UNSUBSCRIBED, class => UnsubscribeEvent );
 
     return;
 }
@@ -451,7 +581,7 @@ sub _unsubscribe_from_events {
 
         $self->send(
             $peer,
-            'unsubscribe',
+            UNSUBSCRIBED,
             class       => UnsubscribeEvent,
             event_names => \@event_names,
         );
@@ -461,6 +591,32 @@ sub _unsubscribe_from_events {
     return;
 }
 
+#pod =method events
+#pod
+#pod   @events = $obj->events;
+#pod   $obj->events( \@event_names | $event_name );
+#pod
+#pod As a getter, returns a list of event names which the object may emit.
+#pod
+#pod As a setter, accepts either an arrayref or a single event name.  Event
+#pod names must a valid Perl identifier (e.g., no C<:> or C<-> characters).
+#pod
+#pod =cut
+
+sub events {
+
+    my $self = shift;
+
+    if ( @_ ) {
+
+	$self->_set__events_arr( @_ );
+	return;
+    }
+
+    return @{ $self->_events_arr };
+
+}
+
 #pod =method detach
 #pod
 #pod   $self->detach;
@@ -475,7 +631,7 @@ sub _unsubscribe_from_events {
 #pod
 #pod =item 2
 #pod
-#pod Emit an C<unsubscribe> event with a L<Net::Object::Peer::UnsubscribeEvent> as a payload.
+#pod Emit an C<unsubscribed> event with a L<Net::Object::Peer::UnsubscribeEvent> as a payload.
 #pod
 #pod =item 3
 #pod
@@ -522,8 +678,10 @@ sub subscriptions {
 #pod
 #pod Broadcast the named event to all subscribed peers.  C<%args> contains
 #pod arguments to be passed the the payload class constructor.  The default
-#pod payload class is a L<Net::Object::Peer::Event> object; use the C<class> key to
-#pod specify an alternate class, which must be derived from B<Net::Object::Peer::Event>.
+#pod payload class is a L<Net::Object::Peer::Event> object; use the
+#pod C<class> key to specify an alternate class, which must be derived from
+#pod B<Net::Object::Peer::Event>.  An attempt to emit an event which is not
+#pod supported by the emitter will cause an exception to be thrown.
 #pod
 #pod =cut
 
@@ -531,6 +689,9 @@ sub emit {
 
     my ( $self, $name ) = ( shift, shift );
 
+    croak( q[\$self does not emit event "$name"\n] )
+      unless $self->emits_events( $name );
+
     $self->_emitter->emit(
         $name,
         class   => 'Net::Object::Peer::Event',
@@ -544,7 +705,8 @@ sub emit {
 #pod   $self->send( $peer, $event_name, %args );
 #pod
 #pod This is similar to the L</emit> method, but only sends the event to the
-#pod specified peer.
+#pod specified peer.  An attempt to emit an event which is not
+#pod supported by the emitter will cause an exception to be thrown.
 #pod
 #pod =cut
 
@@ -552,6 +714,9 @@ sub send {
 
     my ( $self, $peer, $name ) = ( shift, shift, shift );
 
+    croak( q[\$self does not emit event "$name"\n] )
+      unless $self->emits_events( $name );
+
     $self->_emitter->send(
         $peer,
         $name,
@@ -567,28 +732,36 @@ sub send {
 #pod   $self->emit_args( $event_name, @args );
 #pod
 #pod Broadcast the named event to all subscribed peers. C<@args> will be
-#pod passed directly to each subscriber's callback.
+#pod passed directly to each subscriber's callback.  An attempt to emit an event which is not
+#pod supported by the emitter will cause an exception to be thrown.
 #pod
 #pod =cut
 
+before emit_args => sub {
+
+    my ( $self, $name ) = @_;
+
+    croak( q[\$self does not emit event "$name"\n] )
+      unless $self->emits_events( $name );
+};
+
 #pod =method send_args
 #pod
 #pod   $self->send_args( $peer, $event_name, @args );
 #pod
 #pod This is similar to the L</emit_args> method, but only sends the event to the
-#pod specified peer.
+#pod specified peer.  An attempt to emit an event which is not
+#pod supported by the emitter will cause an exception to be thrown.
 #pod
 #pod =cut
 
-# allow emit_args( unsubscribe => $event_name );
-# or emit( unsubscribe ) which will unsubscribe all events from the emitter
-sub __cb_unsubscribe {
+before send_args => sub {
 
-    if ( $_[1]->$_isa( 'Beam::Event' ) ) {
-        splice( @_, 1, 1, $_[1]->emitter );
-    }
-    goto &unsubscribe;
-}
+    my ( $self, $peer, $name ) = @_;
+
+    croak( q[\$self does not emit event "$name"\n] )
+      unless $self->emits_events( $name );
+};
 
 #pod =begin pod_coverage
 #pod
@@ -633,7 +806,7 @@ Net::Object::Peer - Peer-to-Peer Publish/Subscribe Network of Objects
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -645,6 +818,8 @@ version 0.05
  
  has name => is => ( 'ro', required => 1 );
  
+ sub default_events { qw[ hey ] }
+ 
  sub _notify_subscribed {
      my ( $self, $peer, $name ) = @_;
      say $self->name, ":\t@{[ $peer->name ]} subscribed to event $name";
@@ -656,7 +831,7 @@ version 0.05
        ":\t@{[ $event->emitter->name ]} sent @{[$event->name]}";
  }
  
- sub _cb_unsubscribe {
+ sub _cb_unsubscribed {
      my ( $self, $event ) = @_;
      say $self->name, ":\t@{[ $event->emitter->name ]} unsubscribed";
  }
@@ -668,9 +843,9 @@ version 0.05
  my $n2 = Node->new( name => 'N2' );
  my $n3 = Node->new( name => 'N3' );
  
- # Net::Object::Peer provides an "unsubscribe" event; $n1 will be
+ # Net::Object::Peer provides an "unsubscribed" event; $n1 will be
  # notified when $n2 unsubscribes from it
- $n1->subscribe( $n2, 'unsubscribe' );
+ $n1->subscribe( $n2, 'unsubscribed' );
  
  # $n2 and $n3 will be notified when $n1 sends a "hey" event, and $n1
  # will be notified that they have subscribed 
@@ -690,7 +865,7 @@ version 0.05
 
 Resulting in:
 
- N2:	N1 subscribed to event unsubscribe
+ N2:	N1 subscribed to event unsubscribed
  N1:	N2 subscribed to event hey
  N1:	N3 subscribed to event hey
  N2:	N1 sent hey
@@ -732,6 +907,36 @@ C<changed> event.
 
 =head2 Events
 
+An emitter must register the events that it will emit.  Here's how
+
+=over
+
+=item 1
+
+Class defaults
+
+A default set of events for the class may be specified by defining
+the L</default_events> class method, which should return a list
+of event names:
+
+  sub default_events{ qw[ evt1 evt2 evt3 ] }
+
+=item 2
+
+Object defaults
+
+During object construction, the L<events|/new> attribute may be used
+to specify a list of events.
+
+=item 3
+
+Runtime manipulation
+
+The L</events> object method may be used to overwrite the list
+of events.
+
+=back
+
 When a subscriber recieves an event, its registered handler for that
 event type is invoked.  If the object creating the event used the
 L</emit> or L</send> methods,
@@ -766,10 +971,10 @@ then resubscribed.
 
 After a subscriber de-registers a handler, either explicitly via
 L</unsubscribe> or when the object is destroyed, it will L</emit> an
-C<unsubscribe> event with a L<Net::Object::Peer::UnsubscribeEvent>
+C<unsubscribed> event with a L<Net::Object::Peer::UnsubscribeEvent>
 object as a payload.
 
-While emitters are not automatically subscribed to C<"unsubscribe">
+While emitters are not automatically subscribed to C<unsubscribed>
 events, this is easily accomplished by adding code to the emitters'
 C<_notify_subscribed> method.
 
@@ -780,12 +985,63 @@ unsubscribing from other peers' events.
 
 =head1 ATTRIBUTES
 
+=head2 event_handler_prefix
+
+The string which prefixes default event handler method names. See
+L</subscribe>.  It will by default be initialized to the return value
+of the L</default_event_handler_prefix> method.  It may be specified
+during object construction.
+
+For example, the default handler method name for an event named
+C<changed> would be C<_cb_changed>.  The class must provide that
+method. See L</subscribe> for more information.
+
 =head2 addr
 
 A L<Net::Object::Peer::RefAddr> object providing a unique identity for this emitter.
 
 =head1 METHODS
 
+=head2 emits_events
+
+   $bool = $obj->emits_events( @event_names );
+
+Returns true if the object emits I<all> of the named events
+
+=head2 default_events
+
+  @events = $class->default_events;
+
+Returns a list of events which this class will emit, excluding the C<detach> and C<unsubscribed> events.
+The default implementation returns an empty list.  A per object event list may be specified via
+the L</events> attribute or the C<events> option to the L<constructor|/new>.
+
+=head2 new
+
+  $obj = Net::Object::Peer->new( %args | \%args );
+
+Construct a new object.  The following arguments are available:
+
+=over
+
+=item event_handler_prefix => I<string>
+
+The string which prefixes default event handler method names. See L</event_handler_prefix>
+
+=item events => I<string> | I<arrayref>
+
+The name(s) of the event(s) this object will emit (don't include the
+C<unsubscribed> and C<detach> events).  May be a single string or an
+arrayref. If not specified, the list of events will be initialized via the
+L</default_events> class method.
+
+=back
+
+=head2 default_event_handler_prefix
+
+This class method returns the prefix for the default event handler method names.
+It defaults to returning C<_cb_>.
+
 =head2 build_sub
 
   $coderef = $self->build_sub( $emitter, @tuple );
@@ -820,6 +1076,8 @@ Subscribe to one or more events sent by C<$peer>, which must consume
 the L<Net::Object::Peer> role.  If C<$peer> additionally consumes the
 L<Net::Object::Peer::Ephemeral> role, a strong reference to C<$peer>
 is stored. (See  L<Net::Object::Peer::Cookbook/Translation/Proxy Nodes>.)
+An attempt to subscribe to an event the peer does not produce will throw
+an exception.
 
 The event name and the action to be performed when the event is
 emitted are specified by a tuple with the following forms:
@@ -828,7 +1086,8 @@ emitted are specified by a tuple with the following forms:
 
 =item C<< $event_name >>
 
-the event handler will invoke the C<_cb_${event_name}> method on C<$self>.
+the event handler will invoke the C<${prefix}${event_name}> method on C<$self>,
+where C<$prefix> is the L<event_handler_prefix attribute|/event_handler_prefix>.
 
 =item C<< $event_name => { method => $method_name } >>
 
@@ -871,7 +1130,7 @@ for each subscription.
   # Unsubscribe from one or more events emitted by all peers
   $self->unsubscribe( $event_name [, $event_name [, ... ] ] )
 
-Unsubscribe from events/peers. After unsubscription, an I<unsubscribe>
+Unsubscribe from events/peers. After unsubscription, an I<unsubscribed>
 event with a L<Net::Object::Peer::UnsubscribeEvent> as a payload will
 be sent to affected peers who have subscribed to the unsubscribed event(s).
 
@@ -884,6 +1143,16 @@ to unsubscribe from that C<emitter> is unwise.  Instead, pass either
 the event object or the C<addr> field in that object, which is guaranteed
 to identify the actual emitter subscribed to.
 
+=head2 events
+
+  @events = $obj->events;
+  $obj->events( \@event_names | $event_name );
+
+As a getter, returns a list of event names which the object may emit.
+
+As a setter, accepts either an arrayref or a single event name.  Event
+names must a valid Perl identifier (e.g., no C<:> or C<-> characters).
+
 =head2 detach
 
   $self->detach;
@@ -898,7 +1167,7 @@ Unsubscribe from all events from all peers.
 
 =item 2
 
-Emit an C<unsubscribe> event with a L<Net::Object::Peer::UnsubscribeEvent> as a payload.
+Emit an C<unsubscribed> event with a L<Net::Object::Peer::UnsubscribeEvent> as a payload.
 
 =item 3
 
@@ -925,29 +1194,34 @@ L<Net::Object::Peer::Subscrition/find>;
 
 Broadcast the named event to all subscribed peers.  C<%args> contains
 arguments to be passed the the payload class constructor.  The default
-payload class is a L<Net::Object::Peer::Event> object; use the C<class> key to
-specify an alternate class, which must be derived from B<Net::Object::Peer::Event>.
+payload class is a L<Net::Object::Peer::Event> object; use the
+C<class> key to specify an alternate class, which must be derived from
+B<Net::Object::Peer::Event>.  An attempt to emit an event which is not
+supported by the emitter will cause an exception to be thrown.
 
 =head2 send
 
   $self->send( $peer, $event_name, %args );
 
 This is similar to the L</emit> method, but only sends the event to the
-specified peer.
+specified peer.  An attempt to emit an event which is not
+supported by the emitter will cause an exception to be thrown.
 
 =head2 emit_args
 
   $self->emit_args( $event_name, @args );
 
 Broadcast the named event to all subscribed peers. C<@args> will be
-passed directly to each subscriber's callback.
+passed directly to each subscriber's callback.  An attempt to emit an event which is not
+supported by the emitter will cause an exception to be thrown.
 
 =head2 send_args
 
   $self->send_args( $peer, $event_name, @args );
 
 This is similar to the L</emit_args> method, but only sends the event to the
-specified peer.
+specified peer.  An attempt to emit an event which is not
+supported by the emitter will cause an exception to be thrown.
 
 =begin pod_coverage
 
@@ -1033,6 +1307,36 @@ __END__
 #pod
 #pod =head2 Events
 #pod
+#pod An emitter must register the events that it will emit.  Here's how
+#pod
+#pod =over
+#pod
+#pod =item 1
+#pod
+#pod Class defaults
+#pod
+#pod A default set of events for the class may be specified by defining
+#pod the L</default_events> class method, which should return a list
+#pod of event names:
+#pod
+#pod   sub default_events{ qw[ evt1 evt2 evt3 ] }
+#pod
+#pod =item 2
+#pod
+#pod Object defaults
+#pod
+#pod During object construction, the L<events|/new> attribute may be used
+#pod to specify a list of events.
+#pod
+#pod =item 3
+#pod
+#pod Runtime manipulation
+#pod
+#pod The L</events> object method may be used to overwrite the list
+#pod of events.
+#pod
+#pod =back
+#pod
 #pod When a subscriber recieves an event, its registered handler for that
 #pod event type is invoked.  If the object creating the event used the
 #pod L</emit> or L</send> methods,
@@ -1068,10 +1372,10 @@ __END__
 #pod
 #pod After a subscriber de-registers a handler, either explicitly via
 #pod L</unsubscribe> or when the object is destroyed, it will L</emit> an
-#pod C<unsubscribe> event with a L<Net::Object::Peer::UnsubscribeEvent>
+#pod C<unsubscribed> event with a L<Net::Object::Peer::UnsubscribeEvent>
 #pod object as a payload.
 #pod
-#pod While emitters are not automatically subscribed to C<"unsubscribe">
+#pod While emitters are not automatically subscribed to C<unsubscribed>
 #pod events, this is easily accomplished by adding code to the emitters'
 #pod C<_notify_subscribed> method.
 #pod
